/* YOODA : Yet another Object Oriented Database
   Copyright (C) 1994  Eric Abecassis

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the Free
Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#pragma implementation "monitor.hxx"

#include "monitor.hxx"
#include "monitor_clnt.hxx"
#include "config.h"

template class ListVal<InfoClient> ;
template class IterListVal<InfoClient> ;
template SvcSocket& operator>>(SvcSocket&, ListVal<InfoClient>&) ;
template SvcSocket& operator<<(SvcSocket&, const ListVal<InfoClient>&) ;

SvcSocket& operator<<(SvcSocket& svc, InfoClient& tr) {
  svc << tr._name << tr._pid << tr._servers ;
  return svc ;
}

SvcSocket& operator>>(SvcSocket& svc, InfoClient& tr) {
  svc >> tr._name >> tr._pid >> tr._servers ;
  return svc ;
}


void display_bases(ListVal<char*>& l_bases)
{
  IterListVal<char*> iter(l_bases) ;
  for (; iter.more(); iter.next()) {
    cout << "\n\tDatabase <" << iter.get() << ">\n" ;
  }
}

ListVal<char*>& list_servers(char* base)
{
  static ListVal<char*> l_servers ;
  proxy_YoodaMonitor mon[MAX_VUE] ; 
  
  l_servers.clear() ;

  for (int i = 0; (i < MAX_VUE) && (mon[i].import(base) != -1); i++) {
    l_servers += mon[i].getname() ;
  }

  return l_servers ;
}

void display_servers(char* base, ListVal<char*>& l_servers)
{
  cout << "\nDatabase <" << base << ">\n" ;
  IterListVal<char*> iter(l_servers) ;
  for (; iter.more(); iter.next()) {
    cout << "\tserver : " << iter.get() << endl ;
  }
}

void kill_server(char* base, char* server)
{
  proxy_YoodaMonitor mon[MAX_VUE] ; 

  for (int i = 0; (i < MAX_VUE) && (mon[i].import(base) != -1); i++) {
    if (strcmp(server, mon[i].getname()) == 0) {
      mon[i].killServer() ;
      break ;
    }
  }
}

void kill_all_servers(char* base)
{
  proxy_YoodaMonitor mon[MAX_VUE] ; 

  for (int i = 0; (i < MAX_VUE) && (mon[i].import(base) != -1); i++) {
    mon[i].killServer() ;
  }
}

ListVal<InfoClient>& list_clients(char* base)
{
  proxy_YoodaMonitor mon[MAX_VUE] ; 
  static ListVal<InfoClient> list_in, list_out ;

  list_in.clear() ;
  list_out.clear() ;
  for (int i = 0; (i < MAX_VUE) && (mon[i].import(base) != -1); i++) {
    mon[i].listClients(list_in, list_out) ;
    list_in.capture(list_out) ;
  }
  return list_in ;
}

void display_clients(ListVal<InfoClient>& list_in)
{
  IterListVal<InfoClient> iter(list_in) ;
  for (; iter.more(); iter.next()) {
    cout << "\nclient <" << iter.get().pid() << ", "
	 << iter.get().name() << ">"  ;
    cout <<"\n\tuses servers : " ;
    IterListVal<char*> iter2(iter.get().servers()) ;
    for (; iter2.more(); iter2.next()) {
      cout << "\n\t\t" << iter2.get() ;
    }
    cout << endl ;
  }
}

void kill_client(char* base, int pid)
{
  proxy_YoodaMonitor mon[MAX_VUE] ; 

  for (int i = 0; (i < MAX_VUE) && (mon[i].import(base) != -1); i++) {
    mon[i].killClient(pid) ;
  }
}



